==> kubernetes-model-core-6.3.1-sources.jar: io/fabric8/kubernetes/api/model/NodeSystemInfoFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NodeSystemInfoFluentImpl<A extends NodeSystemInfoFluent<A>> extends BaseFluent<A> implements NodeSystemInfoFluent<A>{
  public NodeSystemInfoFluentImpl() {
  }
  public NodeSystemInfoFluentImpl(NodeSystemInfo instance) {
    this.withArchitecture(instance.getArchitecture()); 
    this.withBootID(instance.getBootID()); 
    this.withContainerRuntimeVersion(instance.getContainerRuntimeVersion()); 
    this.withKernelVersion(instance.getKernelVersion()); 
    this.withKubeProxyVersion(instance.getKubeProxyVersion()); 
    this.withKubeletVersion(instance.getKubeletVersion()); 
    this.withMachineID(instance.getMachineID()); 
    this.withOperatingSystem(instance.getOperatingSystem()); 
    this.withOsImage(instance.getOsImage()); 
    this.withSystemUUID(instance.getSystemUUID()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String architecture;
  private String bootID;
  private String containerRuntimeVersion;
  private String kernelVersion;
  private String kubeProxyVersion;
  private String kubeletVersion;
  private String machineID;
  private String operatingSystem;
  private String osImage;
  private String systemUUID;
  private Map<String,Object> additionalProperties;
  public String getArchitecture() {
    return this.architecture;
  }
  public A withArchitecture(String architecture) {
    this.architecture=architecture; return (A) this;
  }
  public Boolean hasArchitecture() {
    return this.architecture != null;
  }
  public String getBootID() {
    return this.bootID;
  }
  public A withBootID(String bootID) {
    this.bootID=bootID; return (A) this;
  }
  public Boolean hasBootID() {
    return this.bootID != null;
  }
  public String getContainerRuntimeVersion() {
    return this.containerRuntimeVersion;
  }
  public A withContainerRuntimeVersion(String containerRuntimeVersion) {
    this.containerRuntimeVersion=containerRuntimeVersion; return (A) this;
  }
  public Boolean hasContainerRuntimeVersion() {
    return this.containerRuntimeVersion != null;
  }
  public String getKernelVersion() {
    return this.kernelVersion;
  }
  public A withKernelVersion(String kernelVersion) {
    this.kernelVersion=kernelVersion; return (A) this;
  }
  public Boolean hasKernelVersion() {
    return this.kernelVersion != null;
  }
  public String getKubeProxyVersion() {
    return this.kubeProxyVersion;
  }
  public A withKubeProxyVersion(String kubeProxyVersion) {
    this.kubeProxyVersion=kubeProxyVersion; return (A) this;
  }
  public Boolean hasKubeProxyVersion() {
    return this.kubeProxyVersion != null;
  }
  public String getKubeletVersion() {
    return this.kubeletVersion;
  }
  public A withKubeletVersion(String kubeletVersion) {
    this.kubeletVersion=kubeletVersion; return (A) this;
  }
  public Boolean hasKubeletVersion() {
    return this.kubeletVersion != null;
  }
  public String getMachineID() {
    return this.machineID;
  }
  public A withMachineID(String machineID) {
    this.machineID=machineID; return (A) this;
  }
  public Boolean hasMachineID() {
    return this.machineID != null;
  }
  public String getOperatingSystem() {
    return this.operatingSystem;
  }
  public A withOperatingSystem(String operatingSystem) {
    this.operatingSystem=operatingSystem; return (A) this;
  }
  public Boolean hasOperatingSystem() {
    return this.operatingSystem != null;
  }
  public String getOsImage() {
    return this.osImage;
  }
  public A withOsImage(String osImage) {
    this.osImage=osImage; return (A) this;
  }
  public Boolean hasOsImage() {
    return this.osImage != null;
  }
  public String getSystemUUID() {
    return this.systemUUID;
  }
  public A withSystemUUID(String systemUUID) {
    this.systemUUID=systemUUID; return (A) this;
  }
  public Boolean hasSystemUUID() {
    return this.systemUUID != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    NodeSystemInfoFluentImpl that = (NodeSystemInfoFluentImpl) o;
    if (architecture != null ? !architecture.equals(that.architecture) :that.architecture != null) return false;
    if (bootID != null ? !bootID.equals(that.bootID) :that.bootID != null) return false;
    if (containerRuntimeVersion != null ? !containerRuntimeVersion.equals(that.containerRuntimeVersion) :that.containerRuntimeVersion != null) return false;
    if (kernelVersion != null ? !kernelVersion.equals(that.kernelVersion) :that.kernelVersion != null) return false;
    if (kubeProxyVersion != null ? !kubeProxyVersion.equals(that.kubeProxyVersion) :that.kubeProxyVersion != null) return false;
    if (kubeletVersion != null ? !kubeletVersion.equals(that.kubeletVersion) :that.kubeletVersion != null) return false;
    if (machineID != null ? !machineID.equals(that.machineID) :that.machineID != null) return false;
    if (operatingSystem != null ? !operatingSystem.equals(that.operatingSystem) :that.operatingSystem != null) return false;
    if (osImage != null ? !osImage.equals(that.osImage) :that.osImage != null) return false;
    if (systemUUID != null ? !systemUUID.equals(that.systemUUID) :that.systemUUID != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(architecture,  bootID,  containerRuntimeVersion,  kernelVersion,  kubeProxyVersion,  kubeletVersion,  machineID,  operatingSystem,  osImage,  systemUUID,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (architecture != null) { sb.append("architecture:"); sb.append(architecture + ","); }
    if (bootID != null) { sb.append("bootID:"); sb.append(bootID + ","); }
    if (containerRuntimeVersion != null) { sb.append("containerRuntimeVersion:"); sb.append(containerRuntimeVersion + ","); }
    if (kernelVersion != null) { sb.append("kernelVersion:"); sb.append(kernelVersion + ","); }
    if (kubeProxyVersion != null) { sb.append("kubeProxyVersion:"); sb.append(kubeProxyVersion + ","); }
    if (kubeletVersion != null) { sb.append("kubeletVersion:"); sb.append(kubeletVersion + ","); }
    if (machineID != null) { sb.append("machineID:"); sb.append(machineID + ","); }
    if (operatingSystem != null) { sb.append("operatingSystem:"); sb.append(operatingSystem + ","); }
    if (osImage != null) { sb.append("osImage:"); sb.append(osImage + ","); }
    if (systemUUID != null) { sb.append("systemUUID:"); sb.append(systemUUID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> kubernetes-model-core-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/NodeSystemInfoFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class NodeSystemInfoFluentImpl<A extends NodeSystemInfoFluent<A>> extends BaseFluent<A> implements NodeSystemInfoFluent<A>{
  public NodeSystemInfoFluentImpl() {
  }
  public NodeSystemInfoFluentImpl(NodeSystemInfo instance) {
    if (instance != null) {
      this.withArchitecture(instance.getArchitecture());
      this.withBootID(instance.getBootID());
      this.withContainerRuntimeVersion(instance.getContainerRuntimeVersion());
      this.withKernelVersion(instance.getKernelVersion());
      this.withKubeProxyVersion(instance.getKubeProxyVersion());
      this.withKubeletVersion(instance.getKubeletVersion());
      this.withMachineID(instance.getMachineID());
      this.withOperatingSystem(instance.getOperatingSystem());
      this.withOsImage(instance.getOsImage());
      this.withSystemUUID(instance.getSystemUUID());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String architecture;
  private String bootID;
  private String containerRuntimeVersion;
  private String kernelVersion;
  private String kubeProxyVersion;
  private String kubeletVersion;
  private String machineID;
  private String operatingSystem;
  private String osImage;
  private String systemUUID;
  private Map<String,Object> additionalProperties;
  public String getArchitecture() {
    return this.architecture;
  }
  public A withArchitecture(String architecture) {
    this.architecture=architecture; return (A) this;
  }
  public Boolean hasArchitecture() {
    return this.architecture != null;
  }
  public String getBootID() {
    return this.bootID;
  }
  public A withBootID(String bootID) {
    this.bootID=bootID; return (A) this;
  }
  public Boolean hasBootID() {
    return this.bootID != null;
  }
  public String getContainerRuntimeVersion() {
    return this.containerRuntimeVersion;
  }
  public A withContainerRuntimeVersion(String containerRuntimeVersion) {
    this.containerRuntimeVersion=containerRuntimeVersion; return (A) this;
  }
  public Boolean hasContainerRuntimeVersion() {
    return this.containerRuntimeVersion != null;
  }
  public String getKernelVersion() {
    return this.kernelVersion;
  }
  public A withKernelVersion(String kernelVersion) {
    this.kernelVersion=kernelVersion; return (A) this;
  }
  public Boolean hasKernelVersion() {
    return this.kernelVersion != null;
  }
  public String getKubeProxyVersion() {
    return this.kubeProxyVersion;
  }
  public A withKubeProxyVersion(String kubeProxyVersion) {
    this.kubeProxyVersion=kubeProxyVersion; return (A) this;
  }
  public Boolean hasKubeProxyVersion() {
    return this.kubeProxyVersion != null;
  }
  public String getKubeletVersion() {
    return this.kubeletVersion;
  }
  public A withKubeletVersion(String kubeletVersion) {
    this.kubeletVersion=kubeletVersion; return (A) this;
  }
  public Boolean hasKubeletVersion() {
    return this.kubeletVersion != null;
  }
  public String getMachineID() {
    return this.machineID;
  }
  public A withMachineID(String machineID) {
    this.machineID=machineID; return (A) this;
  }
  public Boolean hasMachineID() {
    return this.machineID != null;
  }
  public String getOperatingSystem() {
    return this.operatingSystem;
  }
  public A withOperatingSystem(String operatingSystem) {
    this.operatingSystem=operatingSystem; return (A) this;
  }
  public Boolean hasOperatingSystem() {
    return this.operatingSystem != null;
  }
  public String getOsImage() {
    return this.osImage;
  }
  public A withOsImage(String osImage) {
    this.osImage=osImage; return (A) this;
  }
  public Boolean hasOsImage() {
    return this.osImage != null;
  }
  public String getSystemUUID() {
    return this.systemUUID;
  }
  public A withSystemUUID(String systemUUID) {
    this.systemUUID=systemUUID; return (A) this;
  }
  public Boolean hasSystemUUID() {
    return this.systemUUID != null;
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    NodeSystemInfoFluentImpl that = (NodeSystemInfoFluentImpl) o;
    if (!java.util.Objects.equals(architecture, that.architecture)) return false;

    if (!java.util.Objects.equals(bootID, that.bootID)) return false;

    if (!java.util.Objects.equals(containerRuntimeVersion, that.containerRuntimeVersion)) return false;

    if (!java.util.Objects.equals(kernelVersion, that.kernelVersion)) return false;

    if (!java.util.Objects.equals(kubeProxyVersion, that.kubeProxyVersion)) return false;

    if (!java.util.Objects.equals(kubeletVersion, that.kubeletVersion)) return false;

    if (!java.util.Objects.equals(machineID, that.machineID)) return false;

    if (!java.util.Objects.equals(operatingSystem, that.operatingSystem)) return false;

    if (!java.util.Objects.equals(osImage, that.osImage)) return false;

    if (!java.util.Objects.equals(systemUUID, that.systemUUID)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(architecture,  bootID,  containerRuntimeVersion,  kernelVersion,  kubeProxyVersion,  kubeletVersion,  machineID,  operatingSystem,  osImage,  systemUUID,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (architecture != null) { sb.append("architecture:"); sb.append(architecture + ","); }
    if (bootID != null) { sb.append("bootID:"); sb.append(bootID + ","); }
    if (containerRuntimeVersion != null) { sb.append("containerRuntimeVersion:"); sb.append(containerRuntimeVersion + ","); }
    if (kernelVersion != null) { sb.append("kernelVersion:"); sb.append(kernelVersion + ","); }
    if (kubeProxyVersion != null) { sb.append("kubeProxyVersion:"); sb.append(kubeProxyVersion + ","); }
    if (kubeletVersion != null) { sb.append("kubeletVersion:"); sb.append(kubeletVersion + ","); }
    if (machineID != null) { sb.append("machineID:"); sb.append(machineID + ","); }
    if (operatingSystem != null) { sb.append("operatingSystem:"); sb.append(operatingSystem + ","); }
    if (osImage != null) { sb.append("osImage:"); sb.append(osImage + ","); }
    if (systemUUID != null) { sb.append("systemUUID:"); sb.append(systemUUID + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  
}
